powfacpy.PFStudyCases
=====================

.. currentmodule:: powfacpy

.. autoclass:: PFStudyCases

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PFStudyCases.__init__
      ~PFStudyCases.activate_grids
      ~PFStudyCases.activate_study_case
      ~PFStudyCases.add_results_variable
      ~PFStudyCases.copy_obj
      ~PFStudyCases.copy_single_obj
      ~PFStudyCases.create_by_path
      ~PFStudyCases.create_cases
      ~PFStudyCases.create_directory
      ~PFStudyCases.create_in_folder
      ~PFStudyCases.create_scenario
      ~PFStudyCases.create_study_case
      ~PFStudyCases.create_variation
      ~PFStudyCases.delete_obj
      ~PFStudyCases.get_active_project
      ~PFStudyCases.get_active_user_folder
      ~PFStudyCases.get_attr
      ~PFStudyCases.get_attr_by_path
      ~PFStudyCases.get_by_condition
      ~PFStudyCases.get_case_params_value_string
      ~PFStudyCases.get_first_level_folder
      ~PFStudyCases.get_folder_path
      ~PFStudyCases.get_multiple_obj_from_similar_sub_directories
      ~PFStudyCases.get_obj
      ~PFStudyCases.get_parameter_value_string
      ~PFStudyCases.get_path_of_object
      ~PFStudyCases.get_single_obj
      ~PFStudyCases.get_study_cases
      ~PFStudyCases.get_value_of_parameter_for_case
      ~PFStudyCases.handle_case_input
      ~PFStudyCases.handle_condition_of_obj_not_met
      ~PFStudyCases.handle_inclusion_of_subfolders
      ~PFStudyCases.handle_non_existing_obj
      ~PFStudyCases.handle_pf_object_or_path_input
      ~PFStudyCases.handle_single_pf_object_or_path_input
      ~PFStudyCases.is_container
      ~PFStudyCases.path_exists
      ~PFStudyCases.set_attr
      ~PFStudyCases.set_attr_by_path
      ~PFStudyCases.set_parameters
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PFStudyCases.language
      ~PFStudyCases.study_cases
   
   